@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Resolver;
-$Template::Resolver::VERSION = '1.11';
+$Template::Resolver::VERSION = '1.12';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
@@ -62,8 +62,15 @@ sub _init {
 
     $logger->debug('creating new Resolver');
 
-    $self->{entity} = $entity;
-    $self->{transformer} = Template::Transformer->new( $os, _entity_to_properties($entity) );
+    $self->{entity}      = $entity;
+    $self->{transformer} = Template::Transformer->new(
+        $os,
+        _entity_to_properties($entity),
+        (   $options{additional_transforms}
+            ? ( additional_transforms => $options{additional_transforms} )
+            : ()
+        )
+    );
 
     return $self;
 }
@@ -103,7 +110,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -125,6 +132,13 @@ available options are:
 
 =over 4
 
+=item additional_transforms
+
+Additional custom transforms that will be added to the standard transforms.
+Must be a hashref containing transform name to sub reference mappings.  
+The sub reference(s) will be called as a method(s) with a single parameter
+containing the contents of the placeholder.
+
 =item os
 
 The operating system path format used when resolving C<${TEMPLATE_os{xxx}}> placeholders.
