@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Transformer;
-$Template::Transformer::VERSION = '1.11';
+$Template::Transformer::VERSION = '1.12';
 # ABSTRACT: Transformer used by Template::Resolver
 # PODNAME: Template::Transformer
 
@@ -39,7 +39,7 @@ sub _env {
 }
 
 sub _init {
-    my ( $self, $os, $properties ) = @_;
+    my ( $self, $os, $properties, %options ) = @_;
     $logger->debug( 'initializing transformer for ', $os );
 
     $self->{os}         = $os;
@@ -53,6 +53,12 @@ sub _init {
         'perl'       => $self->_wrap_transform( \&_perl ),
         'xml_escape' => $self->_wrap_transform( \&_xml_escape )
     };
+    if ( $options{additional_transforms} ) {
+        foreach my $transform ( keys( %{ $options{additional_transforms} } ) ) {
+            $self->{wrapped_transforms}{$transform} =
+                $self->_wrap_transform( $options{additional_transforms}{$transform} );
+        }
+    }
     lock_hashref( $self->{wrapped_transforms} );
 
     return $self;
@@ -134,7 +140,7 @@ Template::Transformer - Transformer used by Template::Resolver
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 AUTHOR
 
